@@ -4,6 +4,8 @@ from typing import List, Optional, Tuple
 from emmet.core.eos import EOSDoc
 from mp_api.core.client import BaseRester
 
+import warnings
+
 
 class EOSRester(BaseRester[EOSDoc]):
 
@@ -11,10 +13,24 @@ class EOSRester(BaseRester[EOSDoc]):
     document_model = EOSDoc  # type: ignore
     primary_key = "task_id"
 
-    def search_eos_docs(
+    def search_eos_docs(self, *args, **kwargs):  # pragma: no cover
+        """
+        Deprecated
+        """
+
+        warnings.warn(
+            "MPRester.eos.search_eos_docs is deprecated. "
+            "Please use MPRester.eos.search instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+
+        return self.search(*args, **kwargs)
+
+    def search(
         self,
-        volumes: Optional[Tuple[float, float]] = None,
         energies: Optional[Tuple[float, float]] = None,
+        volumes: Optional[Tuple[float, float]] = None,
         sort_fields: Optional[List[str]] = None,
         num_chunks: Optional[int] = None,
         chunk_size: int = 1000,
@@ -25,8 +41,8 @@ class EOSRester(BaseRester[EOSDoc]):
         Query equations of state docs using a variety of search criteria.
 
         Arguments:
-            volumes (Tuple[float,float]): Minimum and maximum volume in A³/atom to consider for EOS plot range.
             energies (Tuple[float,float]): Minimum and maximum energy in eV/atom to consider for EOS plot range.
+            volumes (Tuple[float,float]): Minimum and maximum volume in A³/atom to consider for EOS plot range.
             sort_fields (List[str]): Fields used to sort results. Prefix with '-' to sort in descending order.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
             chunk_size (int): Number of data entries per chunk.
@@ -59,7 +75,7 @@ class EOSRester(BaseRester[EOSDoc]):
             if query_params[entry] is not None
         }
 
-        return super().search(
+        return super()._search(
             num_chunks=num_chunks,
             chunk_size=chunk_size,
             all_fields=all_fields,
